###############
OwnedGiftUnique
###############


.. automodule:: litegram.types.owned_gift_unique
    :members:
    :member-order: bysource
    :undoc-members: True
    :exclude-members: model_config,model_fields
